@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_MULTIPARTJOB_H
-#define MESSAGECOMPOSER_MULTIPARTJOB_H
+#pragma once
 
 #include "contentjobbase.h"
 #include "messagecomposer_export.h"
@@ -35,5 +34,3 @@ private:
     Q_DECLARE_PRIVATE(MultipartJob)
 };
 }
-
-#endif
