@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,30 +8,27 @@
 #include "messagecomposer_debug.h"
 #include "plugineditorinit.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <QFileInfo>
-#include <QSet>
 
 using namespace MessageComposer;
 
 class PluginEditorInitInfo
 {
 public:
-    PluginEditorInitInfo()
-    {
-    }
+    PluginEditorInitInfo() = default;
 
     PimCommon::PluginUtilData pluginData;
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
+    KPluginMetaData data;
     PluginEditorInit *plugin = nullptr;
     bool isEnabled = true;
 };
 
 namespace
 {
-QString pluginVersion()
+QString pluginEditorInitVersion()
 {
     return QStringLiteral("1.0");
 }
@@ -77,11 +74,16 @@ QVector<PimCommon::PluginUtilData> PluginEditorInitManagerPrivate::pluginsDataLi
 
 void PluginEditorInitManagerPrivate::initializePlugins()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("kmail/plugineditorinit"));
+    const QVector<KPluginMetaData> plugins =
+        KPluginMetaData::findPlugins(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/kmail/plugineditorinit"));
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QVectorIterator<KPluginMetaData> i(plugins);
+#else
+    QListIterator<KPluginMetaData> i(plugins);
+#endif
     i.toBack();
     while (i.hasPrevious()) {
         PluginEditorInitInfo info;
@@ -95,7 +97,8 @@ void PluginEditorInitManagerPrivate::initializePlugins()
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
-        if (pluginVersion() == data.version()) {
+        info.data = data;
+        if (pluginEditorInitVersion() == data.version()) {
             info.plugin = nullptr;
             mPluginList.push_back(info);
         } else {
@@ -110,9 +113,8 @@ void PluginEditorInitManagerPrivate::initializePlugins()
 
 void PluginEditorInitManagerPrivate::loadPlugin(PluginEditorInitInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<PluginEditorInit>(q, QVariantList() << item->metaDataFileNameBaseName);
+    if (auto plugin = KPluginFactory::instantiatePlugin<PluginEditorInit>(item->data, q, QVariantList() << item->metaDataFileName).plugin) {
+        item->plugin = plugin;
         item->plugin->setIsEnabled(item->isEnabled);
         item->pluginData.mHasConfigureDialog = item->plugin->hasConfigureDialog();
         mPluginDataList.append(item->pluginData);
@@ -148,10 +150,7 @@ PluginEditorInitManager::PluginEditorInitManager(QObject *parent)
 {
 }
 
-PluginEditorInitManager::~PluginEditorInitManager()
-{
-    delete d;
-}
+PluginEditorInitManager::~PluginEditorInitManager() = default;
 
 PluginEditorInitManager *PluginEditorInitManager::self()
 {
