@@ -11,7 +11,7 @@
 
 #include <QObject>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 class KJob;
 
@@ -55,10 +55,7 @@ private:
     */
     void sendOrQueueMessage(const KMime::Message::Ptr &msg, MessageComposer::MessageSender::SendMethod method = MessageComposer::MessageSender::SendDefault);
 
-private Q_SLOTS:
     void queueJobResult(KJob *job);
-
-private:
-    AkonadiSenderPrivate *const d;
+    std::unique_ptr<AkonadiSenderPrivate> const d;
 };
 }
