@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,6 +7,8 @@
 
 #include "messageviewer_export.h"
 #include <QDialog>
+
+class QPushButton;
 namespace MessageViewer
 {
 class DKIMManageRulesWidget;
@@ -28,6 +30,6 @@ private:
     void slotImport();
     void slotExport();
     DKIMManageRulesWidget *const mRulesWidget;
+    QPushButton *const mExportButton;
 };
 }
-
