@@ -1,16 +1,15 @@
 /*
- * SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "contactdisplaymessagememento.h"
-#include "gravatarsettings.h"
 #include "messageviewer_debug.h"
-#include "settings/messageviewersettings.h"
-#include <Akonadi/Contact/ContactSearchJob>
+#include <Akonadi/ContactSearchJob>
 #include <Gravatar/GravatarResolvUrlJob>
-#include <kio/transferjob.h>
+#include <KIO/TransferJob>
+#include <gravatar/gravatarsettings.h>
 
 using namespace MessageViewer;
 
@@ -69,11 +68,11 @@ void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
                         }
                     } else {
                         QByteArray imageData;
-                        KIO::TransferJob *job = KIO::get(url, KIO::NoReload);
-                        QObject::connect(job, &KIO::TransferJob::data, [&imageData](KIO::Job *, const QByteArray &data) {
+                        KIO::TransferJob *jobTransfert = KIO::get(url, KIO::NoReload);
+                        QObject::connect(jobTransfert, &KIO::TransferJob::data, [&imageData](KIO::Job *, const QByteArray &data) {
                             imageData.append(data);
                         });
-                        if (job->exec()) {
+                        if (jobTransfert->exec()) {
                             if (image.loadFromData(imageData)) {
                                 ok = true;
                             }
@@ -90,16 +89,16 @@ void ContactDisplayMessageMemento::slotSearchJobFinished(KJob *job)
     if (mPhoto.isEmpty() && mPhoto.url().isEmpty()) {
         // No url, no photo => search gravatar
         if (Gravatar::GravatarSettings::self()->gravatarSupportEnabled()) {
-            auto job = new Gravatar::GravatarResolvUrlJob(this);
-            job->setEmail(mEmailAddress);
-            job->setUseDefaultPixmap(Gravatar::GravatarSettings::self()->gravatarUseDefaultImage());
-            job->setFallbackGravatar(Gravatar::GravatarSettings::self()->fallbackToGravatar());
-            job->setUseLibravatar(Gravatar::GravatarSettings::self()->libravatarSupportEnabled());
-            if (job->canStart()) {
-                connect(job, &Gravatar::GravatarResolvUrlJob::finished, this, &ContactDisplayMessageMemento::slotGravatarResolvUrlFinished);
-                job->start();
+            auto resolvUrljob = new Gravatar::GravatarResolvUrlJob(this);
+            resolvUrljob->setEmail(mEmailAddress);
+            resolvUrljob->setUseDefaultPixmap(Gravatar::GravatarSettings::self()->gravatarUseDefaultImage());
+            resolvUrljob->setFallbackGravatar(Gravatar::GravatarSettings::self()->fallbackToGravatar());
+            resolvUrljob->setUseLibravatar(Gravatar::GravatarSettings::self()->libravatarSupportEnabled());
+            if (resolvUrljob->canStart()) {
+                connect(resolvUrljob, &Gravatar::GravatarResolvUrlJob::finished, this, &ContactDisplayMessageMemento::slotGravatarResolvUrlFinished);
+                resolvUrljob->start();
             } else {
-                job->deleteLater();
+                resolvUrljob->deleteLater();
             }
         }
     }
