@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,6 +10,10 @@
 #include <KSharedConfig>
 
 using namespace MessageViewer;
+namespace
+{
+static const char myRemoteContentGroupName[] = "RemoteContent";
+}
 RemoteContentManager::RemoteContentManager(QObject *parent)
     : QObject(parent)
 {
@@ -84,9 +88,10 @@ void RemoteContentManager::loadSettings()
 {
     mRemoveContentInfo.clear();
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group(config, "RemoteContent");
+    KConfigGroup group(config, myRemoteContentGroupName);
     const QStringList blockedUrl = group.readEntry("Blocked", QStringList());
     const QStringList authorizedUrl = group.readEntry("Authorized", QStringList());
+    mRemoveContentInfo.reserve(blockedUrl.count() + authorizedUrl.count());
     for (const QString &url : blockedUrl) {
         RemoteContentInfo info;
         info.setUrl(url);
@@ -104,7 +109,7 @@ void RemoteContentManager::loadSettings()
 void RemoteContentManager::writeSettings()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group(config, "RemoteContent");
+    KConfigGroup group(config, myRemoteContentGroupName);
     QStringList blockedUrl;
     QStringList authorizedUrl;
     for (const RemoteContentInfo &info : std::as_const(mRemoveContentInfo)) {
