@@ -1,19 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef REMOTECONTENTMENU_H
-#define REMOTECONTENTMENU_H
+#pragma once
 
 #include "messageviewer_export.h"
 #include <QMenu>
-#include <QObject>
 namespace MessageViewer
 {
+/**
+ * @brief The RemoteContentMenu class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGEVIEWER_EXPORT RemoteContentMenu : public QMenu
 {
+    Q_OBJECT
 public:
     explicit RemoteContentMenu(QWidget *parent = nullptr);
     ~RemoteContentMenu() override;
@@ -26,13 +29,14 @@ public:
     void clearUrls();
     void appendUrl(const QString &url);
 
+Q_SIGNALS:
+    void updateEmail();
+
 private:
-    void initialize();
     void authorize(const QString &url);
     void slotConfigure();
     QStringList mUrls;
-    QAction *mConfigureRemoteContentAction = nullptr;
+    QAction *const mConfigureRemoteContentAction;
     QList<QAction *> mListAction;
 };
 }
-#endif // REMOTECONTENTMENU_H
