@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,13 +11,9 @@ using namespace MessageViewer;
 MessageWidgetArea::MessageWidgetArea(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins({});
-
 }
 
-MessageWidgetArea::~MessageWidgetArea()
-{
-
-}
+MessageWidgetArea::~MessageWidgetArea() = default;
