@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,7 +28,7 @@ public:
 private:
     void readConfig();
     void writeConfig();
-    MailSourceViewTextBrowserWidget *mRawBrowser = nullptr;
+    MailSourceViewTextBrowserWidget *const mRawBrowser;
     FindBarSourceView *mFindBar = nullptr;
     QTabWidget *mTabWidget = nullptr;
     MailSourceViewTextBrowserWidget *mHtmlBrowser = nullptr;
