@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,7 +24,11 @@ class WEBENGINEVIEWER_EXPORT CheckPhishingUrlCache : public QObject
 public:
     static CheckPhishingUrlCache *self();
 
-    enum UrlStatus { UrlOk = 0, MalWare = 1, Unknown = 2 };
+    enum UrlStatus {
+        UrlOk = 0,
+        MalWare = 1,
+        Unknown = 2,
+    };
 
     explicit CheckPhishingUrlCache(QObject *parent = nullptr);
     ~CheckPhishingUrlCache() override;
@@ -53,4 +57,3 @@ private:
 }
 
 Q_DECLARE_METATYPE(WebEngineViewer::CheckPhishingUrlCache::UrlStatus)
-
