@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef WEBENGINEEXPORTPDFPAGEJOB_H
-#define WEBENGINEEXPORTPDFPAGEJOB_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QObject>
@@ -42,5 +41,3 @@ private:
     QWebEngineView *mWebEngineView = nullptr;
 };
 }
-
-#endif // WEBENGINEEXPORTPDFPAGEJOB_H
